import {
  JsonEncoder
} from "./chunk-AJ3WFXQE.js";
import {
  Emitter
} from "./chunk-F6OVXD4L.js";
import {
  uname
} from "./chunk-ULLOUKBT.js";
import {
  DefaultLogger
} from "./chunk-6KWR5DLV.js";

// src/common/msg/pubsub.ts
var PubSub = class extends Emitter {
  constructor(opt) {
    super();
    this.publish = this.emit.bind(this);
    this.subscribe = this.on.bind(this);
    const { name, encoder = new JsonEncoder(), channel, debug = false } = opt;
    this.channel = channel;
    this.encoder = encoder;
    this.debug = debug;
    this.name = name ?? this.channel.id ?? uname("pubsub");
    this.log = DefaultLogger(`${this.shortId}`);
    if (this.debug) {
      this.channel.on("connect", () => {
        this.log("channel connected");
      });
      this.channel.on("disconnect", () => {
        this.log("channel disconnected");
      });
    }
    this.channel.on("message", async ({ data }) => {
      const info = await this.encoder.decode(data);
      if (this.debug)
        this.log(`channel message, event=${info?.event}, info=`, info);
      else
        this.log(`channel message, event=${info?.event}`);
      if (info) {
        const { event, args } = info;
        await this.emitSuper(event, ...args);
      }
    });
  }
  get shortId() {
    return this.name.substr(0, 6);
  }
  async emitSuper(event, ...args) {
    return await super.emit(event, ...args);
  }
  async emit(event, ...args) {
    try {
      if (this.debug)
        this.log(`emit(${String(event)})`, event);
      else
        this.log(`emit(${String(event)})`, args.length);
      if (!this.channel.isConnected) {
        this.log.warn("channel not connected");
        return false;
      }
      const data = await this.encoder.encode({ event, args });
      this.channel.postMessage(data);
      return true;
    } catch (err) {
      this.log.warn(`emit(${String(event)})`, err);
    }
    return false;
  }
};
function usePubSub(opt) {
  return new PubSub(opt);
}

export {
  PubSub,
  usePubSub
};
//# sourceMappingURL=chunk-22B3ZREI.js.map