import {
  useLevelFilter,
  useNamespaceFilter
} from "./chunk-TN2XVUJ2.js";
import {
  LogLevelError,
  LogLevelInfo,
  LogLevelWarn
} from "./chunk-E6MPGGAE.js";
import {
  renderMessages
} from "./chunk-PIOWR3HK.js";

// src/node/log/log-file.ts
import { createWriteStream, mkdirSync } from "node:fs";
import { dirname, resolve } from "node:path";
import process from "node:process";
var namespaces = {};
function LoggerFileHandler(path, opt = {}) {
  const {
    level = void 0,
    filter = void 0,
    time = true,
    pretty = false
  } = opt;
  path = resolve(process.cwd(), path);
  mkdirSync(dirname(path), { recursive: true });
  const stream = createWriteStream(path, { flags: "a" });
  const matchesNamespace = useNamespaceFilter(filter);
  const matchesLevel = useLevelFilter(level);
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const timeNow = time ? `${(/* @__PURE__ */ new Date()).toISOString()} ` : "";
    const name = msg.name || "";
    const ninfo = namespaces[name || ""];
    if (ninfo == null)
      namespaces[name] = ninfo;
    const args = [
      `[${name || "*"}]`,
      renderMessages(msg.messages, { pretty })
    ];
    function write(...args2) {
      stream.write(`${args2.join("	")}
`);
    }
    switch (msg.level) {
      case LogLevelInfo:
        write(`${timeNow}I|*  `, ...args);
        break;
      case LogLevelWarn:
        write(`${timeNow}W|** `, ...args);
        break;
      case LogLevelError:
        write(`${timeNow}E|***`, ...args);
        break;
      default:
        write(`${timeNow}D|   `, ...args);
        break;
    }
  };
}

export {
  LoggerFileHandler
};
//# sourceMappingURL=chunk-ENOX7MRW.js.map