import {
  isArray,
  isBoolean,
  isRecord
} from "./chunk-EOHXRMVQ.js";
import {
  escapeRegExp
} from "./chunk-ZMFW3O35.js";
import {
  jsonStringifySafe
} from "./chunk-6GHO7LQW.js";

// src/common/csv.ts
var defaultSeparator = ",";
function csvStringify(data, opt = {}) {
  const { separator = defaultSeparator } = opt;
  let body = "";
  if (opt.addBom)
    body = "\uFEFF";
  for (let i = 0; i < data.length; i++) {
    body += `${data[i].map((field) => {
      if (field == null || field === "")
        return "";
      if (isBoolean(field))
        return field ? 1 : 0;
      let s = String(field);
      if (isRecord(field) || isArray(field))
        s = jsonStringifySafe(field);
      if (s.includes('"') || s.includes("\n") || s.includes(separator))
        return `"${s.replace(/"/g, '""')}"`;
      return s;
    }).join(separator)}
`;
  }
  return body;
}
function csvParse(raw, opt = {}) {
  let rxOneValueWithSeparator = /("((?:(?:[^"]*?)(?:"")?)*)"|([^,;\t\n]*))([,;\t]|\n|\r\n)/g;
  if (opt.separator)
    rxOneValueWithSeparator = new RegExp(rxOneValueWithSeparator.source.replaceAll(",;\\t", escapeRegExp(opt.separator)), rxOneValueWithSeparator.flags);
  const lines = [];
  let row = [];
  let m;
  const text = `${raw.replaceAll("\r\n", "\n").trim()}
`;
  while (m = rxOneValueWithSeparator.exec(text)) {
    let value = m[2] ?? m[3] ?? "";
    value = value.replaceAll('""', '"');
    row.push(value);
    if (m[4] === "\n") {
      lines.push(row);
      row = [];
    }
  }
  return lines;
}
function csvParseToObjects(raw, opt = {}) {
  const lines = csvParse(raw, opt);
  const header = lines[0];
  return lines.slice(1).map(
    (l) => Object.fromEntries(l.map((v, i) => [header[i], v]))
  );
}

export {
  csvStringify,
  csvParse,
  csvParseToObjects
};
//# sourceMappingURL=chunk-FG5BB5ND.js.map