import {
  LoggerConsoleHandler
} from "./chunk-B4UKO53B.js";
import {
  parseLogLevel,
  useNamespaceFilter
} from "./chunk-TN2XVUJ2.js";
import {
  LogLevelAll,
  LogLevelDebug,
  LogLevelError,
  LogLevelFatal,
  LogLevelInfo,
  LogLevelWarn
} from "./chunk-E6MPGGAE.js";
import {
  isNotNull
} from "./chunk-EOHXRMVQ.js";

// src/common/log/log-context.ts
function LoggerContext(_prefix = "") {
  let logHandlers = [LoggerConsoleHandler()];
  let logCheckNamespace = (_name) => true;
  let logLock = false;
  let logFactory = LoggerBaseFactory;
  let logDebug = false;
  function LoggerBaseFactory(name = "", level) {
    const logLevel = parseLogLevel(level ?? LogLevelAll);
    function defineForLogLevel(fnLevel, fn) {
      if (logLevel <= fnLevel)
        return fn;
      return () => {
      };
    }
    const emit = (msg) => {
      if (logCheckNamespace(name)) {
        for (const handler of logHandlers) {
          if (handler)
            handler(msg);
        }
      }
    };
    const log = defineForLogLevel(LogLevelDebug, (...messages) => {
      emit({ name, messages, level: LogLevelDebug });
    });
    log.label = name;
    log.extend = function(prefix) {
      return logFactory(name ? `${name}:${prefix}` : prefix);
    };
    log.debug = defineForLogLevel(LogLevelDebug, (...messages) => {
      emit({ name, messages, level: LogLevelDebug });
    });
    log.info = defineForLogLevel(LogLevelInfo, (...messages) => {
      emit({ name, messages, level: LogLevelInfo });
    });
    log.warn = defineForLogLevel(LogLevelWarn, (...messages) => {
      emit({ name, messages, level: LogLevelWarn });
    });
    log.error = defineForLogLevel(LogLevelError, (...messages) => {
      emit({ name, messages, level: LogLevelError });
    });
    log.fatal = defineForLogLevel(LogLevelFatal, (...messages) => {
      emit({ name, messages, level: LogLevelFatal });
      throw new Error(`${messages.map(String).join(" ")}`);
    });
    log.assert = defineForLogLevel(LogLevelFatal, (condition, ...args) => {
      if (condition == null || typeof condition === "number" && Number.isNaN(condition) || !condition)
        log.fatal(...args);
    });
    return log;
  }
  function Logger(name = "", level) {
    const log = logFactory(name, level);
    if (logDebug)
      log.debug(`+++ init of logger "${name}" on level "${log.level}".`);
    return log;
  }
  Logger.registerHandler = function(handler) {
    logHandlers.push(handler);
  };
  Logger.setFilter = function(namespaces) {
    logCheckNamespace = useNamespaceFilter(namespaces);
  };
  Logger.setLock = (lock = true) => logLock = lock;
  Logger.setDebug = (debug = true) => logDebug = debug;
  Logger.setHandlers = (handlers) => {
    if (logFactory !== LoggerBaseFactory)
      logFactory = LoggerBaseFactory;
    if (handlers != null && !logLock)
      logHandlers = [...handlers].filter(isNotNull);
  };
  Logger.level = LogLevelAll;
  Logger.setLogLevel = function(level = LogLevelAll) {
    if (logLock)
      return;
    Logger.level = level;
  };
  Logger.setFactory = function(factory) {
    if (logLock)
      return;
    logFactory = factory;
  };
  return Logger;
}

export {
  LoggerContext
};
//# sourceMappingURL=chunk-Y4YCZV43.js.map