import {
  getNamespaceFilterString,
  joinLogStrings,
  parseLogLevel,
  useLevelFilter,
  useNamespaceFilter
} from "../../chunk-TN2XVUJ2.js";
import {
  LogLevelAll,
  LogLevelDebug,
  LogLevelError,
  LogLevelInfo,
  LogLevelOff,
  LogLevelWarn
} from "../../chunk-E6MPGGAE.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-UO5KXZLS.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-BCFBEP5B.js";
import "../../chunk-EOHXRMVQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-PIOWR3HK.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/log/log-filter.spec.ts
describe("log-filter", () => {
  it("should match", () => {
    {
      const matches = useNamespaceFilter("a");
      expect(matches.filter).toBe("a");
      expect(matches.accept).toEqual([/^a/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("a*");
      expect(matches.filter).toBe("a*");
      expect(matches.accept).toEqual([/^a.*?/]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("a*,b*,-c*");
      expect(matches.filter).toBe("a*,b*,-c*");
      expect(matches.accept).toEqual([/^a.*?/, /^b.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*,-c*");
      expect(matches.filter).toBe("*,-c*");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c.*?/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*,-c");
      expect(matches.filter).toBe("*,-c");
      expect(matches.accept).toEqual([/^.*?/]);
      expect(matches.reject).toEqual([/^c/]);
      expect(matches("a")).toBe(true);
      expect(matches("aa")).toBe(true);
      expect(matches("b:c")).toBe(true);
      expect(matches("c:d")).toBe(false);
    }
    {
      const matches = useNamespaceFilter("*");
      expect(matches.filter).toBe("*");
      expect(matches.accept).toEqual([]);
      expect(matches.reject).toEqual([]);
      expect(matches("a")).toBe(true);
      expect(matches("b:c")).toBe(true);
    }
  });
  it("should interprete filter right", () => {
    expect(getNamespaceFilterString("")).toEqual("");
    expect(getNamespaceFilterString(0)).toEqual("");
    expect(getNamespaceFilterString(false)).toEqual("");
    expect(getNamespaceFilterString("false")).toEqual("");
    expect(getNamespaceFilterString(null)).toEqual("");
    expect(getNamespaceFilterString("*")).toEqual("*");
    expect(getNamespaceFilterString(1)).toEqual("*");
    expect(getNamespaceFilterString(true)).toEqual("*");
    expect(getNamespaceFilterString("true")).toEqual("*");
    expect(getNamespaceFilterString("a:b")).toEqual("a:b");
  });
  it("should filter by level", () => {
    {
      const levelFilter = useLevelFilter("err");
      expect(levelFilter(LogLevelDebug)).toBe(false);
      expect(levelFilter(LogLevelWarn)).toBe(false);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
    {
      const levelFilter = useLevelFilter("adfdfds");
      expect(levelFilter(LogLevelDebug)).toBe(true);
      expect(levelFilter(LogLevelWarn)).toBe(true);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
    {
      const levelFilter = useLevelFilter(LogLevelWarn);
      expect(levelFilter(LogLevelDebug)).toBe(false);
      expect(levelFilter(LogLevelWarn)).toBe(true);
      expect(levelFilter(LogLevelError)).toBe(true);
    }
  });
  it("should identify log level", () => {
    expect(parseLogLevel(false)).toEqual(LogLevelOff);
    expect(parseLogLevel("info")).toEqual(LogLevelInfo);
    expect(parseLogLevel(LogLevelError)).toEqual(LogLevelError);
    expect(parseLogLevel(true)).toEqual(LogLevelAll);
    expect(parseLogLevel(2)).toEqual(LogLevelWarn);
  });
  it("should join strings", () => {
    expect(joinLogStrings("test")).toEqual(["test"]);
    expect(joinLogStrings("test", "more", 1, 2, 3)).toEqual(["test more", 1, 2, 3]);
    expect(joinLogStrings("test", { a: 1 })).toEqual(["test", { a: 1 }]);
    expect(joinLogStrings("test", "a", "b", true, void 0, null, { a: 1 })).toEqual(["test a", "b", true, void 0, null, { a: 1 }]);
  });
});
//# sourceMappingURL=log-filter.spec.js.map