import {
  LoggerContext
} from "../../chunk-Y4YCZV43.js";
import "../../chunk-B4UKO53B.js";
import "../../chunk-TN2XVUJ2.js";
import "../../chunk-E6MPGGAE.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-UO5KXZLS.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-BCFBEP5B.js";
import "../../chunk-EOHXRMVQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-PIOWR3HK.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = LoggerContext();
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = LoggerContext();
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = LoggerContext();
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = LoggerContext();
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.js.map